@@ -66,11 +66,11 @@ def concat_pandas_columns(data, name='concat_column', sep='|', return_data=False
 	:type name: str
 	:type sep: str
 	:type return_data: bool
-	:param return_data: if True, the whole data frome with the new column is returned, otherwise just the column
+	:param return_data: if True, the whole dataframe with the new column is returned, otherwise just the column
 	:rtype: PandasDF
 	"""
 	def concat_row(x):
-		return sep.join([str(value) for value in x.values])
+		return sep.join([str(value) for value in x.values if value is not None])
 
 	data[name] = data.apply(concat_row, axis=1)
 
